bayespy.inference.vmp.nodes.binomial.BinomialDistribution.random
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialDistribution.random